@@ -735,21 +735,38 @@ rsvg_handle_close (RsvgHandle *handle, GError **error)
 {
     RsvgHandlePrivate *priv;
     gboolean read_successfully;
-    gboolean result;
+    gboolean result = FALSE;
 
     g_return_val_if_fail (error == NULL || *error == NULL, FALSE);
     rsvg_return_val_if_fail (handle, FALSE, error);
 
     priv = handle->priv;
 
-    if (priv->hstate == RSVG_HANDLE_STATE_CLOSED_OK
-        || priv->hstate == RSVG_HANDLE_STATE_CLOSED_ERROR) {
+    switch (priv->hstate) {
+    case RSVG_HANDLE_STATE_START:
+        g_set_error (error, RSVG_ERROR, RSVG_ERROR_FAILED, _("no data passed to parser"));
+        priv->hstate = RSVG_HANDLE_STATE_CLOSED_ERROR;
+        result = FALSE;
+        break;
+
+    case RSVG_HANDLE_STATE_LOADING:
+        g_assert (priv->load != NULL);
+        read_successfully = rsvg_load_close (priv->load, error);
+        result = finish_load (handle, read_successfully, error);
+        break;
+
+    case RSVG_HANDLE_STATE_CLOSED_OK:
+    case RSVG_HANDLE_STATE_CLOSED_ERROR:
         /* closing is idempotent */
-        return TRUE;
+        result = TRUE;
+        break;
+
+    default:
+        g_assert_not_reached ();
     }
 
-    read_successfully = rsvg_load_close (priv->load, error);
-    result = finish_load (handle, read_successfully, error);
+    g_assert (priv->hstate == RSVG_HANDLE_STATE_CLOSED_OK
+              || priv->hstate == RSVG_HANDLE_STATE_CLOSED_ERROR);
 
     return result;
 }
@@ -859,6 +876,17 @@ get_base_uri_from_filename (const gchar * filename)
     return base_uri;
 }
 
+static gboolean
+is_at_start_for_setting_base_file (RsvgHandle *handle)
+{
+    if (handle->priv->hstate == RSVG_HANDLE_STATE_START) {
+        return TRUE;
+    } else {
+        g_warning ("Please set the base file or URI before loading any data into RsvgHandle");
+        return FALSE;
+    }
+}
+
 /**
  * rsvg_handle_set_base_uri:
  * @handle: A #RsvgHandle
@@ -875,10 +903,15 @@ rsvg_handle_set_base_uri (RsvgHandle * handle, const char *base_uri)
     gchar *uri;
     GFile *file;
 
-    g_return_if_fail (handle != NULL);
+    g_return_if_fail (RSVG_IS_HANDLE (handle));
 
-    if (base_uri == NULL)
+    if (!is_at_start_for_setting_base_file (handle)) {
         return;
+    }
+
+    if (base_uri == NULL) {
+        return;
+    }
 
     if (path_is_uri (base_uri))
         uri = g_strdup (base_uri);
@@ -911,6 +944,10 @@ rsvg_handle_set_base_gfile (RsvgHandle *handle,
     g_return_if_fail (RSVG_IS_HANDLE (handle));
     g_return_if_fail (G_IS_FILE (base_file));
 
+    if (!is_at_start_for_setting_base_file (handle)) {
+        return;
+    }
+
     priv = handle->priv;
 
     g_object_ref (base_file);
@@ -1050,6 +1087,32 @@ rsvg_handle_create_drawing_ctx(RsvgHandle *handle,
                                  handle->priv->is_testing);
 }
 
+static gboolean
+is_loaded (RsvgHandle *handle)
+{
+    switch (handle->priv->hstate) {
+    case RSVG_HANDLE_STATE_START:
+        g_warning ("RsvgHandle has not been loaded");
+        return FALSE;
+
+    case RSVG_HANDLE_STATE_LOADING:
+        g_warning ("RsvgHandle is still loading; call rsvg_handle_close() first");
+        return FALSE;
+
+    case RSVG_HANDLE_STATE_CLOSED_OK:
+        return TRUE;
+
+    case RSVG_HANDLE_STATE_CLOSED_ERROR:
+        g_warning ("RsvgHandle could not read or parse the SVG; did you check for errors\n"
+                   "during the loading stage?");
+        return FALSE;
+
+    default:
+        g_assert_not_reached();
+        return FALSE;
+    }
+}
+
 /**
  * rsvg_handle_render_cairo_sub:
  * @handle: A #RsvgHandle
@@ -1077,8 +1140,9 @@ rsvg_handle_render_cairo_sub (RsvgHandle * handle, cairo_t * cr, const char *id)
 
     g_return_val_if_fail (handle != NULL, FALSE);
 
-    if (handle->priv->hstate != RSVG_HANDLE_STATE_CLOSED_OK)
+    if (!is_loaded (handle)) {
         return FALSE;
+    }
 
     status = cairo_status (cr);
 
@@ -1151,6 +1215,13 @@ rsvg_handle_render_cairo (RsvgHandle * handle, cairo_t * cr)
 void
 rsvg_handle_get_dimensions (RsvgHandle * handle, RsvgDimensionData * dimension_data)
 {
+    g_return_if_fail (RSVG_IS_HANDLE (handle));
+    g_return_if_fail (dimension_data != NULL);
+
+    if (!is_loaded (handle)) {
+        return;
+    }
+
     /* This function is probably called from the cairo_render functions.
      * To prevent an infinite loop we are saving the state.
      */
@@ -1220,9 +1291,13 @@ rsvg_handle_get_dimensions_sub (RsvgHandle * handle, RsvgDimensionData * dimensi
     int root_width, root_height;
     gboolean res = FALSE;
 
-    g_return_val_if_fail (handle, FALSE);
+    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
     g_return_val_if_fail (dimension_data, FALSE);
 
+    if (!is_loaded (handle)) {
+        return FALSE;
+    }
+
     memset (dimension_data, 0, sizeof (RsvgDimensionData));
 
     if (handle->priv->tree == NULL)
@@ -1296,8 +1371,12 @@ rsvg_handle_get_position_sub (RsvgHandle * handle, RsvgPositionData * position_d
     cairo_rectangle_t ink_rect;
     int width, height;
 
-    g_return_val_if_fail (handle, FALSE);
-    g_return_val_if_fail (position_data, FALSE);
+    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
+    g_return_val_if_fail (position_data != NULL, FALSE);
+ 
+    if (!is_loaded (handle)) {
+        return FALSE;
+    }
 
     memset (position_data, 0, sizeof (*position_data));
 
@@ -1345,7 +1424,11 @@ gboolean
 rsvg_handle_has_sub (RsvgHandle * handle,
                      const char *id)
 {
-    g_return_val_if_fail (handle, FALSE);
+    g_return_val_if_fail (RSVG_IS_HANDLE (handle), FALSE);
+ 
+    if (!is_loaded (handle)) {
+        return FALSE;
+    }
 
     if (G_UNLIKELY (!id || !id[0]))
       return FALSE;
@@ -1383,10 +1466,11 @@ rsvg_handle_get_pixbuf_sub (RsvgHandle * handle, const char *id)
     cairo_surface_t *surface;
     cairo_t *cr;
 
-    g_return_val_if_fail (handle != NULL, NULL);
-
-    if (handle->priv->hstate != RSVG_HANDLE_STATE_CLOSED_OK)
+    g_return_val_if_fail (RSVG_IS_HANDLE (handle), NULL);
+ 
+    if (!is_loaded (handle)) {
         return NULL;
+    }
 
     rsvg_handle_get_dimensions (handle, &dimensions);
     if (!(dimensions.width && dimensions.height))
