@@ -198,14 +198,6 @@ RsvgCssStyles *rsvg_css_styles_new (void);
 G_GNUC_INTERNAL
 void rsvg_css_styles_free (RsvgCssStyles *styles);
 
-/* Implemented in rsvg_internals/src/css.rs */
-G_GNUC_INTERNAL
-void rsvg_css_styles_define (RsvgCssStyles *styles,
-                             const char *selector,
-                             const char *style_name,
-                             const char *style_value,
-                             gboolean important);
-
 /* Implemented in rsvg_internals/src/css.rs */
 G_GNUC_INTERNAL
 void rsvg_css_parse_into_handle (RsvgHandle *handle,
@@ -255,14 +247,9 @@ gboolean rsvg_cond_check_required_extensions (const char *value);
 G_GNUC_INTERNAL
 gboolean rsvg_cond_check_system_language (const char *value);
 
-G_GNUC_INTERNAL
-cairo_surface_t *rsvg_cairo_surface_from_pixbuf (const GdkPixbuf *pixbuf);
 G_GNUC_INTERNAL
 GdkPixbuf *rsvg_cairo_surface_to_pixbuf (cairo_surface_t *surface);
 
-G_GNUC_INTERNAL
-cairo_surface_t *rsvg_cairo_surface_new_from_href (RsvgHandle *handle, const char *href, GError ** error);
-
 /* Defined in rsvg_internals/src/drawing_ctx.rs */
 G_GNUC_INTERNAL
 RsvgDrawingCtx *rsvg_drawing_ctx_new (cairo_t *cr,
@@ -329,6 +316,9 @@ G_GNUC_INTERNAL
 RsvgHandle *rsvg_handle_load_extern (RsvgHandle *handle,
                                      const char *uri);
 
+G_GNUC_INTERNAL
+gboolean rsvg_handle_keep_image_data (RsvgHandle *handle);
+
 G_GNUC_INTERNAL
 char *_rsvg_handle_acquire_data (RsvgHandle *handle,
                                  const char *uri,
