@@ -3,6 +3,7 @@ use std::fmt;
 
 use cairo;
 use cssparser::BasicParseError;
+use glib;
 
 use attributes::Attribute;
 use parsers::ParseError;
@@ -100,6 +101,28 @@ impl From<cairo::Status> for RenderingError {
     }
 }
 
+#[derive(Clone)]
+pub enum LoadingError {
+    Cairo(cairo::Status),
+    EmptyData,
+    Glib(glib::Error),
+    Unknown,
+}
+
+impl From<cairo::Status> for LoadingError {
+    fn from(e: cairo::Status) -> LoadingError {
+        assert!(e != cairo::Status::Success);
+
+        LoadingError::Cairo(e)
+    }
+}
+
+impl From<glib::Error> for LoadingError {
+    fn from(e: glib::Error) -> LoadingError {
+        LoadingError::Glib(e)
+    }
+}
+
 #[cfg(test)]
 pub fn is_parse_error<T>(r: &Result<T, ValueErrorKind>) -> bool {
     match *r {
