@@ -256,7 +256,8 @@ impl Parse for Operator {
                         cow.as_ref().to_string(),
                     ))),
                 ),
-            }).map_err(|_| ValueErrorKind::Value("invalid operator value".to_string()))
+            })
+            .map_err(|_| ValueErrorKind::Value("invalid operator value".to_string()))
     }
 }
 
