@@ -472,7 +472,8 @@ impl FilterContext {
             &opacity,
             &bbox,
             &self.computed_from_node_being_filtered.color.0,
-        ).and_then(|had_paint_server| {
+        )
+        .and_then(|had_paint_server| {
             if had_paint_server {
                 cr.paint();
             }
@@ -523,14 +524,16 @@ impl FilterContext {
                 .and_then(|surface| {
                     SharedImageSurface::new(surface, SurfaceType::SRgb)
                         .map_err(FilterError::CairoError)
-                }).map(FilterInput::StandardInput),
+                })
+                .map(FilterInput::StandardInput),
             Input::StrokePaint => self
                 .get_paint_server_surface(draw_ctx, &values.stroke.0, values.stroke_opacity.0)
                 .map_err(FilterError::CairoError)
                 .and_then(|surface| {
                     SharedImageSurface::new(surface, SurfaceType::SRgb)
                         .map_err(FilterError::CairoError)
-                }).map(FilterInput::StandardInput),
+                })
+                .map(FilterInput::StandardInput),
 
             Input::FilterOutput(ref name) => self
                 .filter_output(name)
