@@ -1365,10 +1365,34 @@ make_property!(
     XmlLang,
     default: "".to_string(), // see create_pango_layout()
     inherits_automatically: true,
-    newtype_parse: String,
+    newtype: String,
+    parse_impl: {
+        impl Parse for XmlLang {
+            type Data = ();
+            type Err = ValueErrorKind;
+
+            fn parse(
+                parser: &mut Parser<'_, '_>,
+                _: Self::Data
+            ) -> Result<XmlLang, ValueErrorKind> {
+                Ok(XmlLang(parser.expect_ident()?.to_string()))
+            }
+        }
+    },
     parse_data_type: ()
 );
 
+#[cfg(test)]
+#[test]
+fn parses_xml_lang() {
+    assert_eq!(
+        XmlLang::parse_str("es-MX", ()).unwrap(),
+        XmlLang("es-MX".to_string())
+    );
+
+    assert!(XmlLang::parse_str("", ()).is_err());
+}
+
 make_property!(
     ComputedValues,
     XmlSpace,
